@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of the python-chess library.
-# Copyright (C) 2012-2016 Niklas Fiekas <niklas.fiekas@backscattering.de>
+# Copyright (C) 2012-2017 Niklas Fiekas <niklas.fiekas@backscattering.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -744,7 +744,7 @@ class Table(object):
 
         fac = 1
         k = 0
-        while i < self.num or k == order or k == order2:
+        while i < self.num or k in [order, order2]:
             if k == order:
                 factor[0] = fac
                 fac *= PFACTOR[norm[0] - 1][f]
