@@ -149,6 +149,11 @@ class SuicideBoard(chess.Board):
         else:
             return not any(self.generate_pseudo_legal_captures())
 
+    def board_fen(self, promoted=None):
+        if promoted is None:
+            promoted = self.has_chess960_castling_rights()
+        return super(SuicideBoard, self).board_fen(promoted=promoted)
+
     def status(self):
         status = super(SuicideBoard, self).status()
         status &= ~chess.STATUS_NO_WHITE_KING
@@ -464,7 +469,7 @@ THREE_CHECK_POLYGLOT_RANDOM_ARRAY = [
 class ThreeCheckBoard(chess.Board):
 
     aliases = ["Three-check", "Three check", "Threecheck", "Three check chess"]
-    uci_variant = "threecheck"
+    uci_variant = "3check"
     starting_fen = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 3+3 0 1"
 
     tbw_suffix = tbz_suffix = None
@@ -560,7 +565,7 @@ class ThreeCheckBoard(chess.Board):
         self.remaining_checks[chess.WHITE] = wc
         self.remaining_checks[chess.BLACK] = bc
 
-    def epd(self, shredder_fen=False, promoted=False, **operations):
+    def epd(self, shredder_fen=False, promoted=None, **operations):
         epd = []
         epd.append(super(ThreeCheckBoard, self).epd(shredder_fen=shredder_fen, promoted=promoted))
         epd.append("%d+%d" % (max(self.remaining_checks[chess.WHITE], 0), max(self.remaining_checks[chess.BLACK], 0)))
@@ -654,10 +659,11 @@ class CrazyhouseBoard(chess.Board):
         if move.drop:
             self.pockets[self.turn].add(move.drop)
         elif self.is_capture(move):
-            if chess.BB_SQUARES[move.to_square] & self.promoted:
+            if self.is_en_passant(move) or chess.BB_SQUARES[move.to_square] & self.promoted:
                 self.pockets[self.turn].remove(chess.PAWN)
             else:
                 self.pockets[self.turn].remove(self.piece_type_at(move.to_square))
+        return move
 
     def _push_capture(self, move, capture_square, piece_type, was_promoted):
         if was_promoted:
@@ -703,7 +709,7 @@ class CrazyhouseBoard(chess.Board):
             if move.drop == chess.PAWN and chess.BB_SQUARES[move.to_square] & chess.BB_BACKRANKS:
                 return False
 
-            return self.pockets[self.turn].count(move.drop) >= 0
+            return self.pockets[self.turn].count(move.drop) > 0
         else:
             return super(CrazyhouseBoard, self).is_pseudo_legal(move)
 
@@ -768,13 +774,12 @@ class CrazyhouseBoard(chess.Board):
         self.pockets[chess.WHITE] = white_pocket
         self.pockets[chess.BLACK] = black_pocket
 
-    def fen(self, promoted=True):
-        return super(CrazyhouseBoard, self).fen(promoted=promoted)
+    def board_fen(self, promoted=None):
+        if promoted is None:
+            promoted = True
+        return super(CrazyhouseBoard, self).board_fen(promoted=promoted)
 
-    def shredder_fen(self, promoted=True):
-        return super(CrazyhouseBoard, self).shredder_fen(promoted=promoted)
-
-    def epd(self, shredder_fen=False, promoted=True, **operations):
+    def epd(self, shredder_fen=False, promoted=None, **operations):
         epd = super(CrazyhouseBoard, self).epd(shredder_fen=shredder_fen, promoted=promoted)
         board_part, info_part = epd.split(" ", 1)
         return "%s[%s%s] %s" % (board_part, str(self.pockets[chess.WHITE]).upper(), str(self.pockets[chess.BLACK]), info_part)
